summaryrefslogtreecommitdiffstats
path: root/net/test/remote_test_server.h
diff options
context:
space:
mode:
Diffstat (limited to 'net/test/remote_test_server.h')
-rw-r--r--net/test/remote_test_server.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/net/test/remote_test_server.h b/net/test/remote_test_server.h
index b617bab..417eda8b 100644
--- a/net/test/remote_test_server.h
+++ b/net/test/remote_test_server.h
@@ -23,9 +23,10 @@ class RemoteTestServer : public BaseTestServer {
const std::string& host,
const FilePath& document_root);
// Initialize a HTTPS TestServer with a specific set of HTTPSOptions.
// |document_root| must be a relative path under the root tree.
- RemoteTestServer(const HTTPSOptions& https_options,
+ RemoteTestServer(Type type,
+ const SSLOptions& ssl_options,
const FilePath& document_root);
virtual ~RemoteTestServer();
@@ -23,9 +23,10 @@ class RemoteTestServer : public BaseTestServer {
const std::string& host,
const FilePath& document_root);
- // Initialize a HTTPS TestServer with a specific set of HTTPSOptions.
+ // Initialize a TestServer with a specific set of SSLOptions.
// |document_root| must be a relative path under the root tree.